==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/outputs/DataCollectionEndpointResourceResponseIdentity.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Managed service identity of the resource.
 * @property principalId The service principal ID of the system assigned identity. This property will only be provided for a system assigned identity.
 * @property tenantId The tenant ID of the system assigned identity. This property will only be provided for a system assigned identity.
 * @property type Type of managed service identity (where both SystemAssigned and UserAssigned types are allowed).
 * @property userAssignedIdentities The set of user assigned identities associated with the resource. The userAssignedIdentities dictionary keys will be ARM resource ids in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}. The dictionary values can be empty objects ({}) in requests.
 */
public data class DataCollectionEndpointResourceResponseIdentity(
    public val principalId: String,
    public val tenantId: String,
    public val type: String,
    public val userAssignedIdentities: Map<String, UserAssignedIdentityResponse>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.insights.outputs.DataCollectionEndpointResourceResponseIdentity):
            DataCollectionEndpointResourceResponseIdentity =
            DataCollectionEndpointResourceResponseIdentity(
                principalId = javaType.principalId(),
                tenantId = javaType.tenantId(),
                type = javaType.type(),
                userAssignedIdentities = javaType.userAssignedIdentities().map({ args0 ->
                    args0.key.to(
                        args0.value.let({ args0 ->
                            com.pulumi.azurenative.insights.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                        }),
                    )
                }).toMap(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/insights/kotlin/outputs/DataCollectionEndpointResourceResponseIdentity.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Managed service identity of the resource.
 * @property principalId The service principal ID of the system assigned identity. This property will only be provided for a system assigned identity.
 * @property tenantId The tenant ID of the system assigned identity. This property will only be provided for a system assigned identity.
 * @property type Type of managed service identity (where both SystemAssigned and UserAssigned types are allowed).
 * @property userAssignedIdentities The set of user assigned identities associated with the resource. The userAssignedIdentities dictionary keys will be ARM resource ids in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}. The dictionary values can be empty objects ({}) in requests.
 */
public data class DataCollectionEndpointResourceResponseIdentity(
    public val principalId: String,
    public val tenantId: String,
    public val type: String,
    public val userAssignedIdentities: Map<String, UserAssignedIdentityResponse>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.insights.outputs.DataCollectionEndpointResourceResponseIdentity): DataCollectionEndpointResourceResponseIdentity =
            DataCollectionEndpointResourceResponseIdentity(
                principalId = javaType.principalId(),
                tenantId = javaType.tenantId(),
                type = javaType.type(),
                userAssignedIdentities = javaType.userAssignedIdentities().map({ args0 ->
                    args0.key.to(
                        args0.value.let({ args0 ->
                            com.pulumi.azurenative.insights.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                        }),
                    )
                }).toMap(),
            )
    }
}
